@@ -25,11 +25,6 @@ func TestCommandName(t *testing.T) {
 		{"foo[bar]", "foobar", "foo", true, true},
 		{"foo[bar]", "foobar", "fo", false, true},
 		{"foo[bar]", "foobar", "", false, true},
-		{"foo[bar]", "foobar", "foo[bar]", false, false},
-		{"foo[bar]", "foobar", "foobar]", false, false},
-		{"foo[bar]", "foobar", "foo[]", false, false},
-		{"foo[bar]", "foobar", "foo[", false, false},
-		{"foo[bar]", "foobar", "[", false, false},
 		{"[bar]", "bar", "foobar", false, false},
 		{"[bar]", "bar", "bar", true, true},
 		{"[bar]", "bar", "bra", false, false},
